@@ -40,6 +40,8 @@ __license__ = "Apache License, Version 2.0"
 import pickle
 import threading
 
+from . import config
+from . import legacy
 from . import redisdb
 from . import component
 from . import exceptions
@@ -88,6 +90,18 @@ class MemoryBus(Bus):
         Bus._unload(self, *args, **kwargs)
         self._events = None
 
+    def _get_state(self):
+        state = Bus._get_state(self)
+        state.update(_events = self._events)
+        return state
+
+    def _set_state(self, state):
+        Bus._set_state(self, state)
+        _events = state.get("_events", {})
+        for name, methods in legacy.iteritems(_events):
+            for method in methods:
+                self.bind(name, method)
+
 class RedisBus(Bus):
 
     SERIALIZER = pickle
@@ -122,7 +136,11 @@ class RedisBus(Bus):
 
     def _load(self, *args, **kwargs):
         Bus._load(self, *args, **kwargs)
+        self._name = config.conf("BUS_NAME", self.owner.name_i)
+        self._name = config.conf("BUS_SCOPE", self._name)
+        self._name = kwargs.pop("name", self._name)
         self._serializer = kwargs.pop("serializer", self.__class__.SERIALIZER)
+        self._global_channel = kwargs.pop("global_channel", self.__class__.GLOBAL_CHANNEL)
         self._events = dict()
         self._open()
 
@@ -131,12 +149,25 @@ class RedisBus(Bus):
         self._events = None
         self._close()
 
+    def _get_state(self):
+        state = Bus._get_state(self)
+        state.update(_events = self._events)
+        return state
+
+    def _set_state(self, state):
+        Bus._set_state(self, state)
+        _events = state.get("_events", {})
+        for name, methods in legacy.iteritems(_events):
+            for method in methods:
+                self.bind(name, method)
+
     def _open(self):
         cls = self.__class__
+        channel = self._to_channel(self._global_channel)
         self._redis = redisdb.get_connection()
         self._redis.ping()
         self._pubsub = self._redis.pubsub()
-        self._pubsub.subscribe(cls.GLOBAL_CHANNEL)
+        self._pubsub.subscribe(channel)
         self._listener = RedisListener(self)
         self._listener.start()
 
@@ -144,11 +175,13 @@ class RedisBus(Bus):
         self._pubsub.unsubscribe()
         self._listener.join()
         self._redis = None
+        self._pubsub = None
         self._listener = None
 
     def _loop(self, safe = True):
         for item in self._pubsub.listen():
             channel = item.get("channel", None)
+            channel = legacy.str(channel)
             type = item.get("type", None)
             data = item.get("data", None)
             if not type in ("message",): continue
@@ -157,25 +190,28 @@ class RedisBus(Bus):
             data = self._serializer.loads(data)
             methods = self._events.get(name, [])
             for method in methods:
-                if safe: self.owner.schedule(
-                    method,
-                    args = data["args"],
-                    kwargs = data["kwargs"],
-                    timeout = -1,
-                    safe = True
-                )
-                else: method(
-                    *data["args"],
-                    **data["kwargs"]
-                )
+                if safe:
+                    self.owner.schedule(
+                        method,
+                        args = data["args"],
+                        kwargs = data["kwargs"],
+                        timeout = -1,
+                        safe = True
+                    )
+                else:
+                    method(
+                        *data["args"],
+                        **data["kwargs"]
+                    )
 
     def _to_channel(self, name):
-        return self.owner.name_i + ":" + name
+        return self._name + ":" + name
 
 class RedisListener(threading.Thread):
 
     def __init__(self, bus):
-        threading.Thread.__init__(self)
+        threading.Thread.__init__(self, name = "RedisListener")
+        self.daemon = True
         self._bus = bus
 
     def run(self):
