@@ -128,7 +128,7 @@ def get_db(name = None):
 
 def drop_db(name = None):
     db = get_db(name = name)
-    names = db.collection_names()
+    names = _list_names(db)
     for name in names:
         if name.startswith("system."): continue
         db.drop_collection(name)
@@ -161,12 +161,27 @@ def is_mongo(obj):
     if bson and isinstance(obj, bson.DBRef): return True
     return False
 
-def is_new():
-    return int(_pymongo().version[0]) >= 3 if pymongo else False
+def is_new(major = 3, minor = 0, patch = 0):
+    _major, _minor, _patch = _version_t()
+    if _major > major: return True
+    elif _major < major: return False
+    if _minor > minor: return True
+    elif _minor < minor: return False
+    if _patch >= patch: return True
+    else: return False
+
+def _list_names(db, *args, **kwargs):
+    if is_new(3, 7): return db.list_collection_names()
+    else: return db.collection_names()
+
+def _count(store, *args, **kwargs):
+    if len(args) == 0: args = [{}]
+    if is_new(3, 7): return store.count_documents(*args, **kwargs)
+    return store.count(*args, **kwargs)
 
 def _store_find_and_modify(store, *args, **kwargs):
-    if is_new(): store.find_one_and_update(*args, **kwargs)
-    else: store.find_and_modify(*args, **kwargs)
+    if is_new(): return store.find_one_and_update(*args, **kwargs)
+    else: return store.find_and_modify(*args, **kwargs)
 
 def _store_insert(store, *args, **kwargs):
     if is_new(): store.insert_one(*args, **kwargs)
@@ -194,10 +209,17 @@ def _store_ensure_index_many(store, *args, **kwargs):
         _args[0] = [(_args[0], direction)]
         _store_ensure_index(store, *_args, **kwargs)
 
+def _version_t():
+    pymongo_l = _pymongo()
+    if hasattr(pymongo_l, "_version_t"): return pymongo_l._version_t
+    major_s, minor_s, patch_s = pymongo.version.split(".", 2)
+    pymongo_l._version_t = (int(major_s), int(minor_s), int(patch_s))
+    return pymongo_l._version_t
+
 def _pymongo(verify = True):
     if verify: util.verify(
         not pymongo == None,
-        message = "pymongo library not available",
+        message = "PyMongo library not available",
         exception = exceptions.OperationalError
     )
     return pymongo
