@@ -146,6 +146,7 @@ class Request(object):
         self.json = False
         self.code = 200
         self.location = prefix + util.quote(path).lstrip("/")
+        self.encoding = "utf-8"
         self.content_type = None
         self.cache_control = None
         self.authorization = None
@@ -202,6 +203,7 @@ class Request(object):
         self.json = None
         self.code = None
         self.location = None
+        self.encoding = None
         self.content_type = None
         self.cache_control = None
         self.authorization = None
@@ -288,6 +290,7 @@ class Request(object):
             prefix = self.prefix,
             query = self.query,
             scheme = self.scheme,
+            encoding = self.encoding,
             content_type = self.content_type,
             cache_conrtol = self.cache_control
         )
@@ -364,6 +367,12 @@ class Request(object):
             _value.extend(value)
             self.args[key] = _value
 
+    def get_encoding(self):
+        return self.encoding
+
+    def set_encoding(self, encoding):
+        self.encoding = encoding
+
     def get_content_type(self):
         return self.content_type
 
@@ -390,15 +399,23 @@ class Request(object):
         if normalize: name = name.title()
         return self.in_headers.get(name, default)
 
-    def set_header(self, name, value, normalize = False):
+    def set_header(self, name, value, normalize = False, replace = True):
         if normalize: name = name.title()
+        if not replace and name in self.out_headers: return
         self.out_headers[name] = legacy.ascii(value)
 
+    def ensure_header(self, name, value, normalize = False):
+        self.set_header(name, value, normalize = normalize, replace = False)
+
     def set_headers(self, headers):
         if not headers: return
         for name, value in headers.items():
             self.set_header(name, value)
 
+    def set_headers_l(self, headers_l):
+        for name, value in headers_l:
+            self.set_header(name, value)
+
     def has_header_in(self, name, insensitive = True):
         if insensitive: name = name.title()
         return name in self.in_headers
@@ -671,7 +688,7 @@ class Request(object):
             self.args["sid"] = self.args[alias]
 
     def set_session(self, create = False):
-        # tries to retrieves the session id (sid) from all the
+        # tries to retrieves the session id (SID) from all the
         # possible sources so that something may be used in the
         # identification of the current request
         sid = self.cookies.get("sid", None)
@@ -728,9 +745,6 @@ class Request(object):
         code_s = str(self.code) + " " + code_s
         return code_s
 
-    def get_encoding(self):
-        return "utf-8"
-
     def get_sdate(self, format = "%d/%b/%Y:%H:%M:%S +0000"):
         sdate = datetime.datetime.utcfromtimestamp(self.stime)
         return sdate.strftime(format)
