@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2017 Hive Solutions Lda.
+# Copyright (c) 2008-2018 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -163,3 +163,81 @@ class CacheTest(unittest.TestCase):
 
         self.assertEqual("third" in cache, False)
         self.assertEqual(cache.length(), 0)
+
+    def test_redis_hash(self):
+        try: cache = appier.RedisCache.new(hash = True)
+        except:
+            if not hasattr(self, "skipTest"): return
+            self.skipTest("No Redis server present")
+
+        cache["first"] = b"1"
+        cache["second"] = b"2"
+
+        self.assertEqual(cache["first"], b"1")
+        self.assertEqual(cache["second"], b"2")
+
+        cache.set_item("first", b"1", timeout = -1)
+
+        self.assertEqual("first" in cache, False)
+        self.assertRaises(KeyError, lambda: cache["first"])
+
+        cache.set_item("first", b"1", timeout = 3600)
+
+        self.assertEqual(cache["first"], b"1")
+
+        cache.set_item("first", b"1", expires = time.time() - 1)
+
+        self.assertEqual("first" in cache, False)
+        self.assertRaises(KeyError, lambda: cache["first"])
+
+        cache.set_item("first", b"1", expires = time.time() + 3600)
+
+        self.assertEqual(cache["first"], b"1")
+
+        cache["third"] = b"3"
+
+        self.assertEqual("third" in cache, True)
+        self.assertNotEqual(cache.length(), 0)
+
+        cache.clear()
+
+        self.assertEqual("third" in cache, False)
+        self.assertEqual(cache.length(), 0)
+
+    def test_serialized(self):
+        cache = appier.FileCache.new()
+        cache = appier.SerializedCache(cache)
+
+        cache["first"] = 1
+        cache["second"] = 2
+
+        self.assertEqual(cache["first"], 1)
+        self.assertEqual(cache["second"], 2)
+
+        cache.set_item("first", 1, timeout = -1)
+
+        self.assertEqual("first" in cache, False)
+        self.assertRaises(KeyError, lambda: cache["first"])
+
+        cache.set_item("first", 1, timeout = 3600)
+
+        self.assertEqual(cache["first"], 1)
+
+        cache.set_item("first", 1, expires = time.time() - 1)
+
+        self.assertEqual("first" in cache, False)
+        self.assertRaises(KeyError, lambda: cache["first"])
+
+        cache.set_item("first", 1, expires = time.time() + 3600)
+
+        self.assertEqual(cache["first"], 1)
+
+        cache["third"] = 3
+
+        self.assertEqual("third" in cache, True)
+        self.assertNotEqual(cache.length(), 0)
+
+        cache.clear()
+
+        self.assertEqual("third" in cache, False)
+        self.assertEqual(cache.length(), 0)
