@@ -334,6 +334,59 @@ class UtilTest(unittest.TestCase):
             appier.legacy.u("joamag@hive.pt <joamag@hive.pt>")
         ])
 
+    def test_email_name(self):
+        result = appier.email_name("João Magalhães <joamag@hive.pt>")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "João Magalhães")
+
+        result = appier.email_name(appier.legacy.u("João Magalhães <joamag@hive.pt>"))
+        self.assertEqual(type(result), appier.legacy.UNICODE)
+        self.assertEqual(result, appier.legacy.u("João Magalhães"))
+
+        result = appier.email_name(appier.legacy.u(" joamag@hive.pt "))
+        self.assertEqual(type(result), appier.legacy.UNICODE)
+        self.assertEqual(result, appier.legacy.u("joamag@hive.pt"))
+
+        result = appier.email_name(appier.legacy.u("joamag"))
+        self.assertEqual(result, None)
+
+        result = appier.email_name(appier.legacy.u(""))
+        self.assertEqual(result, None)
+
+        result = appier.email_name([
+            appier.legacy.u("joamag@hive.pt"),
+            appier.legacy.u("joamag@hive.pt"),
+            None
+        ])
+        self.assertEqual(type(result), list)
+        self.assertEqual(result, [
+            appier.legacy.u("joamag@hive.pt"),
+            appier.legacy.u("joamag@hive.pt")
+        ])
+
+        result = appier.email_name([
+            appier.legacy.u("joamag"),
+            appier.legacy.u("joamag@hive.pt"),
+            None
+        ])
+        self.assertEqual(type(result), list)
+        self.assertEqual(result, [
+            appier.legacy.u("joamag@hive.pt")
+        ])
+
+        result = appier.email_name([
+            appier.legacy.u(""),
+            None
+        ])
+        self.assertEqual(type(result), list)
+        self.assertEqual(result, [])
+
+        result = appier.email_name([
+            appier.legacy.u("")
+        ])
+        self.assertEqual(type(result), list)
+        self.assertEqual(result, [])
+
     def test_email_base(self):
         result = appier.email_base("João Magalhães <joamag@hive.pt>")
         self.assertEqual(type(result), str)
@@ -347,6 +400,12 @@ class UtilTest(unittest.TestCase):
         self.assertEqual(type(result), appier.legacy.UNICODE)
         self.assertEqual(result, appier.legacy.u("joamag@hive.pt"))
 
+        result = appier.email_base(appier.legacy.u("joamag"))
+        self.assertEqual(result, None)
+
+        result = appier.email_base(appier.legacy.u(""))
+        self.assertEqual(result, None)
+
         result = appier.email_base([
             appier.legacy.u("joamag@hive.pt"),
             appier.legacy.u("joamag@hive.pt"),
@@ -358,6 +417,29 @@ class UtilTest(unittest.TestCase):
             appier.legacy.u("joamag@hive.pt")
         ])
 
+        result = appier.email_base([
+            appier.legacy.u("joamag"),
+            appier.legacy.u("joamag@hive.pt"),
+            None
+        ])
+        self.assertEqual(type(result), list)
+        self.assertEqual(result, [
+            appier.legacy.u("joamag@hive.pt")
+        ])
+
+        result = appier.email_base([
+            appier.legacy.u(""),
+            None
+        ])
+        self.assertEqual(type(result), list)
+        self.assertEqual(result, [])
+
+        result = appier.email_base([
+            appier.legacy.u(""),
+        ])
+        self.assertEqual(type(result), list)
+        self.assertEqual(result, [])
+
     def test_date_to_timestamp(self):
         result = appier.date_to_timestamp("29/06/1984")
         self.assertEqual(type(result), int)
@@ -494,6 +576,44 @@ class UtilTest(unittest.TestCase):
         self.assertEqual(type(result), str)
         self.assertEqual(result, "Hello World")
 
+    def test_unescape(self):
+        result = appier.unescape("foo$,bar", escape = "$")
+        self.assertEqual(result, "foo,bar")
+
+        result = appier.unescape("foo$$,bar", escape = "$")
+        self.assertEqual(result, "foo$,bar")
+
+        result = appier.unescape("$$foo$,bar$$$$", escape = "$")
+        self.assertEqual(result, "$foo,bar$$")
+
+    def test_split_unescape(self):
+        result = appier.split_unescape("foo bar")
+        self.assertEqual(result, ["foo", "bar"])
+
+        result = appier.split_unescape("foo bar hello world", max = 2)
+        self.assertEqual(result, ["foo", "bar", "hello world"])
+
+        result = appier.split_unescape("foo,bar", ",")
+        self.assertEqual(result, ["foo", "bar"])
+
+        result = appier.split_unescape("foo$,bar", ",", escape = "$")
+        self.assertEqual(result, ["foo,bar"])
+
+        result = appier.split_unescape("foo$$,bar", ",", escape = "$", unescape = True)
+        self.assertEqual(result, ["foo$", "bar"])
+
+        result = appier.split_unescape("foo$$,bar", ",", escape = "$", unescape = False)
+        self.assertEqual(result, ["foo$$", "bar"])
+
+        result = appier.split_unescape("foo$", ",", escape = "$", unescape = True)
+        self.assertEqual(result, ["foo$"])
+
+        result = appier.split_unescape("foo\\\\\\:bar", ":", unescape = True)
+        self.assertEqual(result, ["foo\\:bar"])
+
+        result = appier.split_unescape("foo\\\\:bar", ":", unescape = True)
+        self.assertEqual(result, ["foo\\", "bar"])
+
     def test_is_content_type(self):
         result = appier.is_content_type("text/plain", "text/plain")
         self.assertEqual(result, True)
@@ -813,3 +933,14 @@ class FileTupleTest(unittest.TestCase):
 
         self.assertEqual(file.read(5), b"hello")
         self.assertEqual(file.tell(), 5)
+
+class BaseThreadTest(unittest.TestCase):
+
+    def test_basic(self):
+        thread = appier.BaseThread(
+            args = (),
+            daemon = True,
+            name = "Test"
+        )
+
+        self.assertEqual(thread.name, "Test")
