@@ -357,14 +357,14 @@ def email_mime(base, encoding = "utf-8"):
 def email_name(base):
     base_t = type(base)
     if base_t in SEQUENCE_TYPES:
-        return [value for value in (email_base(base) for base in base) if value]
+        return [value for value in (email_name(base) for base in base if email_name(base)) if value]
     name, _email = email_parts(base)
     return name
 
 def email_base(base):
     base_t = type(base)
     if base_t in SEQUENCE_TYPES:
-        return [value for value in (email_base(base) for base in base) if value]
+        return [value for value in (email_base(base) for base in base if email_base(base)) if value]
     _name, email = email_parts(base)
     return email
 
@@ -927,6 +927,81 @@ def unquote(value, *args, **kwargs):
     if is_bytes: value = value.decode("utf-8")
     return value
 
+def unescape(value, escape = "\\"):
+    """
+    Unescapes the provided string value using the provided escape
+    character as the reference for the unescape operation.
+
+    This is considered to be a very expensive operation and so it
+    should be used carefully.
+
+    :type value: String
+    :param value: The string value that is going to be unescape.
+    :rtype: String
+    :return: The final unescaped value.
+    """
+
+    result = []
+    iterator = iter(value)
+    for char in iterator:
+        if char == escape:
+            try:
+                result.append(next(iterator))
+            except StopIteration:
+                result.append(escape)
+        else:
+            result.append(char)
+    return "".join(result)
+
+def split_unescape(value, delimiter = " ", max = -1, escape = "\\", unescape = True):
+    """
+    Splits the provided string around the delimiter character that
+    has been provided and allows proper escaping of it using the
+    provided escape character.
+
+    This is considered to be a very expensive operation when compared
+    to the simples split operation and so it should be used carefully.
+
+    :type value: String
+    :param value: The string value that is going to be split around
+    the proper delimiter value taking into account the escaping.
+    :type delimiter: String
+    :param delimiter: The delimiter character to be used in the split
+    operation.
+    :type max: int
+    :param max: The maximum number of split operations that are going
+    to be performed by this operation.
+    :type escape: String
+    :param escape: The "special" escape character that will allow the
+    delimiter to be also present in the choices selection.
+    :type unescape: bool
+    :param unescape: If the final resulting string should be already
+    unescaped (normalized).
+    :rtype: List
+    :return: The final list containing the multiple string parts separated
+    by the delimiter character and respecting the escape sequences.
+    """
+
+    result = []
+    current = []
+    iterator = iter(value)
+    count = 0
+    for char in iterator:
+        if char == escape:
+            try:
+                if not unescape: current.append(escape)
+                current.append(next(iterator))
+            except StopIteration:
+                if unescape: current.append(escape)
+        elif char == delimiter and not count == max:
+            result.append("".join(current))
+            current = []
+            count += 1
+        else:
+            current.append(char)
+    result.append("".join(current))
+    return result
+
 def call_safe(callable, *args, **kwargs):
     """
     Method used to call a callable object using a "safe" approach,
@@ -1796,30 +1871,32 @@ def sanitize(function, kwargs):
         removal.append(name)
     for name in removal: del kwargs[name]
 
-def verify(condition, message = None, code = None, exception = None):
+def verify(condition, message = None, code = None, exception = None, **kwargs):
     if condition: return
     exception = exception or exceptions.AssertionError
-    kwargs = dict()
+    kwargs = dict(kwargs)
     if not message == None: kwargs["message"] = message
     if not code == None: kwargs["code"] = code
     raise exception(**kwargs)
 
-def verify_equal(first, second, message = None, code = None, exception = None):
+def verify_equal(first, second, message = None, code = None, exception = None, **kwargs):
     message = message or "Expected %s got %s" % (repr(second), repr(first))
     return verify(
         first == second,
         message = message,
         code = code,
-        exception = exception
+        exception = exception,
+        **kwargs
     )
 
-def verify_not_equal(first, second, message = None, code = None, exception = None):
+def verify_not_equal(first, second, message = None, code = None, exception = None, **kwargs):
     message = message or "Expected %s not equal to %s" % (repr(first), repr(second))
     return verify(
         not first == second,
         message = message,
         code = code,
-        exception = exception
+        exception = exception,
+        **kwargs
     )
 
 def execute(args, command = None, path = None, shell = None, encoding = None):
